@@ -8,6 +8,8 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
+from sys import stderr as SE
+
 import pyutilib.component.core
 
 pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
@@ -31,7 +33,7 @@ try:
         try:
             plugin_class = entrypoint.load()
         except Exception, err:
-            print "Error loading coopr.opt entry point:", str(err),' entrypoint="%s"' % str(entrypoint)
+            SE.write( "Error loading coopr.opt entry point: %s  entrypoint='%s'\n" % (err, entrypoint) )
 except Exception, err:
-    print "Error loading coopr.opt entry points"
+    SE.write( "Error loading coopr.opt entry points\n" )
 
