@@ -78,7 +78,7 @@ def __solver_call__(self, _name=None, args=[], **kwds):
             if not opt is None:
                 opt.set_options('solver='+_name)
     if not opt is None and not subsolver is None:
-        opt.set_options('solver='+subsolver)
+        opt.set_options('subsolver='+subsolver)
     #print opt.options
     return opt
 pyutilib.misc.add_method(SolverFactory, __solver_call__, name='__call__')
@@ -126,7 +126,12 @@ class OptSolver(Plugin):
         if 'options' in kwds and not kwds['options'] is None:
             for key in kwds['options']:
                 setattr(self.options,key,kwds['options'][key])
+
+        # the symbol map is an attribute of the solver plugin only because
+        # it is generated in presolve and used to tag results so they are
+        # interpretable - basically, it persists across multiple methods.
         self._symbol_map=None
+        
         self._problem_format=None
         self._results_format=None
         self._valid_problem_formats=[]
@@ -209,6 +214,10 @@ class OptSolver(Plugin):
         postsolve_completion_time = time.time()
 
         result._symbol_map = self._symbol_map
+        # if you don't do this, you won't be able to delete the instance - because
+        # the symbol map holds a reference to the instance! which is fine, as
+        # technically the symbol map isn't 'good' past the life of the solve().
+        self._symbol_map = None
 
         if self._report_timing is True:
             print "Presolve time=%0.2f seconds" % (presolve_completion_time-initial_time)
