@@ -8,6 +8,6 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-import OS
+#import OS
 import sol
 import res
