@@ -22,23 +22,47 @@ from coopr.opt import SolverResults
 from pyutilib.component.core import alias
 
 
-class ResultsReader_results(results.AbstractResultsReader):
+class ResultsReader_yaml(results.AbstractResultsReader):
     """
-    Class that reads in a *.results file and generates a
+    Class that reads in a *.yml file and generates a
     SolverResults object.
     """
 
     alias(str(ResultsFormat.yaml))
 
     def __init__(self):
-        results.AbstractResultsReader.__init__(self,ResultsFormat.yaml)
+        results.AbstractResultsReader.__init__(self, ResultsFormat.yaml)
 
-    def __call__(self, filename, res=None, soln=None):
+    def __call__(self, filename, res=None, soln=None, suffixes=[]):
         """
         Parse a *.results file
         """
         if res is None:
             res = SolverResults()
         #
-        res.read(filename)
+        res.read(filename, using_yaml=True)
         return res
+
+
+
+class ResultsReader_json(results.AbstractResultsReader):
+    """
+    Class that reads in a *.jsn file and generates a
+    SolverResults object.
+    """
+
+    alias(str(ResultsFormat.json))
+
+    def __init__(self):
+        results.AbstractResultsReader.__init__(self, ResultsFormat.json)
+
+    def __call__(self, filename, res=None, soln=None, suffixes=[]):
+        """
+        Parse a *.results file
+        """
+        if res is None:
+            res = SolverResults()
+        #
+        res.read(filename, using_yaml=False)
+        return res
+
