@@ -77,12 +77,12 @@ class SolverResults(MapContainer):
                             (str(type(idx)), str(obj.index)))
                 obj = obj.component()
                 label = obj.name + ':' + ','.join(codedIdx)
-            if obj.parent is None or obj.parent() is None:
+            if obj._parent is None or obj._parent() is None:
                 return label
-            obj = obj.parent()
-            while obj.parent is not None and obj.parent() is not None:
+            obj = obj._parent()
+            while obj._parent is not None and obj._parent() is not None:
                 label = str(obj.name) + '.' + label
-                obj = obj.parent()
+                obj = obj._parent()
             return label
             
         sMap = self._symbol_map
